animated.gif
============

Source: <https://www.animatedimages.org/img-animated-cat-image-0072-58439.htm>


transparency.png
================

Source: <https://commons.wikimedia.org/wiki/Category:Portable_Network_Graphics?uselang=de#/media/File:PNG_transparency_demonstration_1.png>


sunflower.jpg
=============

Source: <https://commons.wikimedia.org/wiki/Category:JPEG_file_format?uselang=de#/media/File:Sunflower_as.jpg>


svg-file.svg
============

Source: <https://en.wikipedia.org/wiki/File:Firefox_logo,_2019.svg>
